package com.ruoyi.goods.mapper;

import java.util.List;
import com.ruoyi.goods.domain.TCanteenSubmenu;

/**
 * 子菜单Mapper接口
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
public interface TCanteenSubmenuMapper 
{
    /**
     * 查询子菜单
     * 
     * @param submenuId 子菜单主键
     * @return 子菜单
     */
    public TCanteenSubmenu selectTCanteenSubmenuBySubmenuId(Long submenuId);

    /**
     * 查询子菜单列表
     * 
     * @param tCanteenSubmenu 子菜单
     * @return 子菜单集合
     */
    public List<TCanteenSubmenu> selectTCanteenSubmenuList(TCanteenSubmenu tCanteenSubmenu);

    /**
     * 新增子菜单
     * 
     * @param tCanteenSubmenu 子菜单
     * @return 结果
     */
    public int insertTCanteenSubmenu(TCanteenSubmenu tCanteenSubmenu);

    /**
     * 修改子菜单
     * 
     * @param tCanteenSubmenu 子菜单
     * @return 结果
     */
    public int updateTCanteenSubmenu(TCanteenSubmenu tCanteenSubmenu);

    /**
     * 删除子菜单
     * 
     * @param submenuId 子菜单主键
     * @return 结果
     */
    public int deleteTCanteenSubmenuBySubmenuId(Long submenuId);

    /**
     * 批量删除子菜单
     * 
     * @param submenuIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTCanteenSubmenuBySubmenuIds(Long[] submenuIds);
}
