package com.ruoyi.goods.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.goods.domain.TCanteenSubmenu;
import com.ruoyi.goods.service.ITCanteenSubmenuService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 子菜单Controller
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@RestController
@RequestMapping("/goods/submenu")
public class TCanteenSubmenuController extends BaseController
{
    @Autowired
    private ITCanteenSubmenuService tCanteenSubmenuService;

    /**
     * 查询子菜单列表
     */
    @PreAuthorize("@ss.hasPermi('goods:submenu:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCanteenSubmenu tCanteenSubmenu)
    {
        startPage();
        List<TCanteenSubmenu> list = tCanteenSubmenuService.selectTCanteenSubmenuList(tCanteenSubmenu);
        return getDataTable(list);
    }

    /**
     * 导出子菜单列表
     */
    @PreAuthorize("@ss.hasPermi('goods:submenu:export')")
    @Log(title = "子菜单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCanteenSubmenu tCanteenSubmenu)
    {
        List<TCanteenSubmenu> list = tCanteenSubmenuService.selectTCanteenSubmenuList(tCanteenSubmenu);
        ExcelUtil<TCanteenSubmenu> util = new ExcelUtil<TCanteenSubmenu>(TCanteenSubmenu.class);
        util.exportExcel(response, list, "子菜单数据");
    }

    /**
     * 获取子菜单详细信息
     */
    @PreAuthorize("@ss.hasPermi('goods:submenu:query')")
    @GetMapping(value = "/{submenuId}")
    public AjaxResult getInfo(@PathVariable("submenuId") Long submenuId)
    {
        return success(tCanteenSubmenuService.selectTCanteenSubmenuBySubmenuId(submenuId));
    }

    /**
     * 新增子菜单
     */
    @PreAuthorize("@ss.hasPermi('goods:submenu:add')")
    @Log(title = "子菜单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCanteenSubmenu tCanteenSubmenu)
    {
        return toAjax(tCanteenSubmenuService.insertTCanteenSubmenu(tCanteenSubmenu));
    }

    /**
     * 修改子菜单
     */
    @PreAuthorize("@ss.hasPermi('goods:submenu:edit')")
    @Log(title = "子菜单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCanteenSubmenu tCanteenSubmenu)
    {
        return toAjax(tCanteenSubmenuService.updateTCanteenSubmenu(tCanteenSubmenu));
    }

    /**
     * 删除子菜单
     */
    @PreAuthorize("@ss.hasPermi('goods:submenu:remove')")
    @Log(title = "子菜单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{submenuIds}")
    public AjaxResult remove(@PathVariable Long[] submenuIds)
    {
        return toAjax(tCanteenSubmenuService.deleteTCanteenSubmenuBySubmenuIds(submenuIds));
    }
}
